"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GroupLayer = void 0;
const listener_layes_1 = require("./listener.layes");
class GroupLayer extends listener_layes_1.ListenerLayer {
    constructor(page, browser, options, ev) {
        super(page, browser, options, ev);
        this.page = page;
        this.browser = browser;
        this.options = options;
        this.ev = ev;
    }
    /**
     * Creates a new chat group
     * @param {string} groupName Group name
     * @param {(string | string[])} contacts Participants id '000000000000@c.us'
     */
    async createGroup(groupName, contacts) {
        return new Promise(async (resolve, reject) => {
            const result = await this.page
                .evaluate(({ groupName, contacts }) => API.createGroup(groupName, contacts), { groupName, contacts })
                .catch();
            if (result.erro == true) {
                return reject(result);
            }
            else {
                return resolve(result);
            }
        });
    }
    /**
     * Adds participant to Group
     * @param {string} groupId Chat id ('0000000000-00000000@g.us' or '000000000000000000@g.us')
     * @param {(string | string[])} contacts Participants id '000000000000@c.us'
     */
    async addParticipant(groupId, contacts) {
        return new Promise(async (resolve, reject) => {
            const result = await this.page
                .evaluate(({ groupId, contacts }) => API.addParticipant(groupId, contacts), { groupId, contacts })
                .catch();
            if (result.erro == true) {
                return reject(result);
            }
            else {
                return resolve(result);
            }
        });
    }
    /**
     * Parameters to change group description
     * @param {string} groupId group number
     * @param {string} description group description
     */
    async setGroupDescription(groupId, description) {
        return new Promise(async (resolve, reject) => {
            const result = await this.page.evaluate(({ groupId, description }) => {
                return API.setGroupDescription(groupId, description);
            }, { groupId, description });
            if (result.erro == true) {
                return reject(result);
            }
            else {
                return resolve(result);
            }
        });
    }
}
exports.GroupLayer = GroupLayer;
//# sourceMappingURL=group.layer.js.map